@@ -7,7 +7,13 @@ from typing import List, Optional, Union
 import requests
 from pydantic import HttpUrl
 
-from dagnostics.core.models import ErrorAnalysis, ErrorCategory, ErrorSeverity, LogEntry
+from dagnostics.core.models import (
+    AppConfig,
+    ErrorAnalysis,
+    ErrorCategory,
+    ErrorSeverity,
+    LogEntry,
+)
 from dagnostics.llm.prompts import (
     get_categorization_prompt,
     get_error_extraction_prompt,
@@ -33,15 +39,17 @@ class OllamaProvider(LLMProvider):
         self,
         base_url: Union[str, HttpUrl] = "http://localhost:11434",
         model: str = "mistral",
+        timeout: int = 120,
     ):
         self.base_url = str(base_url).rstrip("/")
         self.model = model
+        self.timeout = timeout
 
     def generate_response(self, prompt: str, **kwargs) -> str:
         payload = {"model": self.model, "prompt": prompt, "stream": False, **kwargs}
         try:
             response = requests.post(
-                f"{self.base_url}/api/generate", json=payload, timeout=60
+                f"{self.base_url}/api/generate", json=payload, timeout=self.timeout
             )
             response.raise_for_status()
             return response.json()["response"]
@@ -221,8 +229,9 @@ class AnthropicProvider(LLMProvider):
 class LLMEngine:
     """Provider-agnostic LLM interface for error analysis"""
 
-    def __init__(self, provider: LLMProvider):
+    def __init__(self, provider: LLMProvider, config: Optional[AppConfig] = None):
         self.provider = provider
+        self.config = config
 
     def extract_error_message(self, log_entries: List[LogEntry]) -> ErrorAnalysis:
         """Extract and analyze error from log entries"""
@@ -251,6 +260,7 @@ class LLMEngine:
             dag_id=log_entries[0].dag_id if log_entries else "unknown",
             task_id=log_entries[0].task_id if log_entries else "unknown",
             provider_type=provider_type,
+            config=self.config,
         )
 
         try:
@@ -304,6 +314,7 @@ class LLMEngine:
             dag_id=log_entries[0].dag_id if log_entries else "unknown",
             task_id=log_entries[0].task_id if log_entries else "unknown",
             provider_type=provider_type,
+            config=self.config,
         )
 
         try:
@@ -367,7 +378,9 @@ class LLMEngine:
     def categorize_error(self, error_message: str, context: str = "") -> ErrorCategory:
         """Categorize error into predefined categories"""
 
-        prompt = get_categorization_prompt(error_message=error_message, context=context)
+        prompt = get_categorization_prompt(
+            error_message=error_message, context=context, config=self.config
+        )
 
         try:
             response = self.provider.generate_response(prompt, temperature=0.0)
@@ -383,6 +396,7 @@ class LLMEngine:
             error_message=error_analysis.error_message,
             category=error_analysis.category.value,
             severity=error_analysis.severity.value,
+            config=self.config,
         )
 
         try:
